@@ -443,7 +443,7 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
         self.last_test_slice = test_slice
         return eval_slice, test_slice, predictors, tt, tt_true
 
-    def unroll_features(self, dates, feature_names, display_slices = False, gradient = True, n_samples = 5000):
+    def unroll_features(self, dates, feature_names, display_slices = False, display_shap = True, gradient = True, n_samples = 5000):
         self.handle_callback('begin_fit')
         rows_list = []
         dates_list = []
@@ -463,6 +463,9 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
             else:
                 features_dico = self.eval_predictor_importance(me_features, me_pred, feature_names)
             rows_list.append(features_dico)
+            if display_shap:
+                print('Shapley values')
+                print(pd.DataFrame(rows_list).sum(axis=1).sum())
             dates_list.append(dates[test_slice.start])
 
             ### loss computation
